Colour Vision Deficiency
========================

Machado, Oliveira and Fernandes (2009)
--------------------------------------

``colour``

.. currentmodule:: colour

.. autosummary::
    :toctree: generated/

    msds_cmfs_anomalous_trichromacy_Machado2009
    matrix_anomalous_trichromacy_Machado2009
    matrix_cvd_Machado2009

**Dataset**

``colour``

.. currentmodule:: colour

.. autosummary::
    :toctree: generated/

    CVD_MATRICES_MACHADO2010
